==> ring_20190822.1.aaa3449.tar.gz: ring-project/lrc/translations/lrc_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" sourcelanguage="en" version="2.0">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/qtwrapper/callmanager_wrap.h" line="315"/>
        <source>Me</source>
        <translation>Ik</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="60"/>
        <source>Hold</source>
        <translation>In wacht zetten</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="62"/>
        <source>Talking</source>
        <translation>Praten</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="64"/>
        <source>ERROR</source>
        <translation>FOUT</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="66"/>
        <source>Incoming</source>
        <translation>Inkomend</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="68"/>
        <source>Calling</source>
        <translation>Bellen</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="70"/>
        <source>Connecting</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="72"/>
        <source>Searching</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="74"/>
        <source>Inactive</source>
        <translation>Inactief</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="76"/>
        <location filename="../src/api/call.h" line="82"/>
        <source>Finished</source>
        <translation>Beëindigd</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="78"/>
        <source>Timeout</source>
        <translation>Time-out</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="80"/>
        <source>Peer busy</source>
        <translation>Peer is bezet</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="84"/>
        <source>Communication established</source>
        <translation>Communicatie tot stand gebracht</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1272"/>
        <location filename="../src/conversationmodel.cpp" line="1661"/>
        <location filename="../src/conversationmodel.cpp" line="1924"/>
        <source>Invitation received</source>
        <translation>Uitnodiging ontvangen</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1273"/>
        <source>Contact added</source>
        <translation>Contact toegevoegd</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1315"/>
        <location filename="../src/conversationmodel.cpp" line="1322"/>
        <source>Invitation accepted</source>
        <translation>Uitnodiging geaccepteerd</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1532"/>
        <source>ð Outgoing call</source>
        <translation>ð Uitgaande oproep</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1534"/>
        <source>ð Incoming call</source>
        <translation>ð Inkomende oproep</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1547"/>
        <source>ð Outgoing call - </source>
        <translation>ð Uitgaande oproep -</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1550"/>
        <source>ð Incoming call - </source>
        <translation>ð Inkomende oproep -</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1554"/>
        <source>ð½ Missed outgoing call</source>
        <translation>ð½ Gemiste uitgaande oproep</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1556"/>
        <source>ð½ Missed incoming call</source>
        <translation>ð½ Gemiste inkomende oproep</translation>
    </message>
    <message>
        <location filename="../src/avmodel.cpp" line="311"/>
        <location filename="../src/avmodel.cpp" line="332"/>
        <source>default</source>
        <translation>standaard</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="45"/>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="46"/>
        <source>Trying</source>
        <translation>Poging</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="47"/>
        <source>Ringing</source>
        <translation>Gaat over</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="48"/>
        <source>Being Forwarded</source>
        <translation>Bezig met doorschakelen</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="49"/>
        <source>Queued</source>
        <translation>In wachtrij</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="50"/>
        <source>Progress</source>
        <translation>Voortgang</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="51"/>
        <source>OK</source>
        <translation>Oké</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="52"/>
        <source>Accepted</source>
        <translation>Geaccepteerd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="53"/>
        <source>Multiple Choices</source>
        <translation>Meerdere mogelijkheden</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="54"/>
        <source>Moved Permanently</source>
        <translation>Permanent verplaatst</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="55"/>
        <source>Moved Temporarily</source>
        <translation>Tijdelijk verplaatst</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="56"/>
        <source>Use Proxy</source>
        <translation>Proxy gebruiken</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="57"/>
        <source>Alternative Service</source>
        <translation>Alternatieve dienst</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="58"/>
        <source>Bad Request</source>
        <translation>Slecht verzoek</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="59"/>
        <source>Unauthorized</source>
        <translation>Niet geautoriseerd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="60"/>
        <source>Payment Required</source>
        <translation>Betaling vereist</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="61"/>
        <source>Forbidden</source>
        <translation>Verboden</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="62"/>
        <source>Not Found</source>
        <translation>Niet gevonden</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="63"/>
        <source>Method Not Allowed</source>
        <translation>Methode niet toegestaan</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="64"/>
        <location filename="../src/newcallmodel.cpp" line="84"/>
        <source>Not Acceptable</source>
        <translation>Niet acceptabel</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="65"/>
        <source>Proxy Authentication Required</source>
        <translation>Proxy-authenticatie vereist</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="66"/>
        <source>Request Timeout</source>
        <translation>Time-out aanvragen</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="67"/>
        <source>Gone</source>
        <translation>Weg</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="68"/>
        <source>Request Entity Too Large</source>
        <translation>Verzoeksentiteit te groot</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="69"/>
        <source>Request URI Too Long</source>
        <translation>Verzoeks-URI te lang</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="70"/>
        <source>Unsupported Media Type</source>
        <translation>Niet-ondersteund mediatype</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="71"/>
        <source>Unsupported URI Scheme</source>
        <translation>Niet-ondersteund URI-schema</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="72"/>
        <source>Bad Extension</source>
        <translation>Slechte extensie</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="73"/>
        <source>Extension Required</source>
        <translation>Extensie vereist</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="74"/>
        <source>Session Timer Too Small</source>
        <translation>Sessietimer te klein</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="75"/>
        <source>Interval Too Brief</source>
        <translation>Interval te kort</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="76"/>
        <source>Temporarily Unavailable</source>
        <translation>Tijdelijk niet beschikbaar</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="77"/>
        <source>Call TSX Does Not Exist</source>
        <translation>Oproep-TSX bestaat niet</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="78"/>
        <source>Loop Detected</source>
        <translation>Lus gedetecteerd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="79"/>
        <source>Too Many Hops</source>
        <translation>Te veel sprongen</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="80"/>
        <source>Address Incomplete</source>
        <translation>Onvolledig adres</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="81"/>
        <source>Ambiguous</source>
        <translation>Ambigu</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="82"/>
        <source>Busy</source>
        <translation>Bezig</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="83"/>
        <source>Request Terminated</source>
        <translation>Verzoek beëindigd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="85"/>
        <source>Bad Event</source>
        <translation>Slechte gebeurtenis</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="86"/>
        <source>Request Updated</source>
        <translation>Verzoek bijgewerkt</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="87"/>
        <source>Request Pending</source>
        <translation>Verzoek in afwachting</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="88"/>
        <source>Undecipherable</source>
        <translation>Onleesbaar</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="89"/>
        <source>Internal Server Error</source>
        <translation>Interne serverfout</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="90"/>
        <source>Not Implemented</source>
        <translation>Niet geïmplementeerd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="91"/>
        <source>Bad Gateway</source>
        <translation>Slechte gateway</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="92"/>
        <source>Service Unavailable</source>
        <translation>Dienst niet beschikbaar</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="93"/>
        <source>Server Timeout</source>
        <translation>Servertime-out</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="94"/>
        <source>Version Not Supported</source>
        <translation>Versie niet ondersteund</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="95"/>
        <source>Message Too Large</source>
        <translation>Bericht te groot</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="96"/>
        <source>Precondition Failure</source>
        <translation>Pre-voorwaardefout</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="97"/>
        <source>Busy Everywhere</source>
        <translation>Overal bezig</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="98"/>
        <source>Call Refused</source>
        <translation>Oproep geweigerd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="99"/>
        <source>Does Not Exist Anywhere</source>
        <translation>Bestaat nergens</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="100"/>
        <source>Not Acceptable Anywhere</source>
        <translation>Nergens acceptabel</translation>
    </message>
</context>
<context>
    <name>lrc::ContactModelPimpl</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="403"/>
        <source>Searchingâ¦</source>
        <translation>Bezig met zoekenâ¦</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="760"/>
        <source>Invalid ID</source>
        <translation>Ongeldig ID</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="763"/>
        <source>Not found</source>
        <translation>Niet gevonden</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="766"/>
        <source>Couldn&apos;t lookupâ¦</source>
        <translation>Kon niet opzoekenâ¦</translation>
    </message>
</context>
<context>
    <name>lrc::api::ContactModel</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="374"/>
        <source>Bad URI scheme</source>
        <translation>Verkeerd URI-schema</translation>
    </message>
</context>
</TS>

==> ring_20191025.1.074a237.tar.gz: ring-project/lrc/translations/lrc_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" sourcelanguage="en" version="2.0">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/qtwrapper/callmanager_wrap.h" line="315"/>
        <source>Me</source>
        <translation>Ik</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="60"/>
        <source>Hold</source>
        <translation>In wacht zetten</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="62"/>
        <source>Talking</source>
        <translation>Praten</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="64"/>
        <source>ERROR</source>
        <translation>FOUT</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="66"/>
        <source>Incoming</source>
        <translation>Inkomend</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="68"/>
        <source>Calling</source>
        <translation>Bellen</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="70"/>
        <source>Connecting</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="72"/>
        <source>Searching</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="74"/>
        <source>Inactive</source>
        <translation>Inactief</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="76"/>
        <location filename="../src/api/call.h" line="82"/>
        <source>Finished</source>
        <translation>Beëindigd</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="78"/>
        <source>Timeout</source>
        <translation>Time-out</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="80"/>
        <source>Peer busy</source>
        <translation>Peer is bezet</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="84"/>
        <source>Communication established</source>
        <translation>Communicatie tot stand gebracht</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="135"/>
        <location filename="../src/authority/storagehelper.cpp" line="856"/>
        <source>Invitation received</source>
        <translation>Uitnodiging ontvangen</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="132"/>
        <location filename="../src/authority/storagehelper.cpp" line="854"/>
        <source>Contact added</source>
        <translation>Contact toegevoegd</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="106"/>
        <location filename="../src/authority/storagehelper.cpp" line="112"/>
        <location filename="../src/authority/storagehelper.cpp" line="852"/>
        <source>Outgoing call</source>
        <translation>Uitgaande oproep</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="108"/>
        <location filename="../src/authority/storagehelper.cpp" line="119"/>
        <source>Incoming call</source>
        <translation>Inkomende oproep</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="115"/>
        <location filename="../src/authority/storagehelper.cpp" line="850"/>
        <source>Missed outgoing call</source>
        <translation>Gemiste uitgaande oproep</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="122"/>
        <source>Missed incoming call</source>
        <translation>Gemiste inkomende oproep</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="137"/>
        <location filename="../src/authority/storagehelper.cpp" line="858"/>
        <source>Invitation accepted</source>
        <translation>Uitnodiging geaccepteerd</translation>
    </message>
    <message>
        <location filename="../src/avmodel.cpp" line="312"/>
        <location filename="../src/avmodel.cpp" line="333"/>
        <source>default</source>
        <translation>standaard</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="48"/>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="49"/>
        <source>Trying</source>
        <translation>Poging</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="50"/>
        <source>Ringing</source>
        <translation>Gaat over</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="51"/>
        <source>Being Forwarded</source>
        <translation>Bezig met doorschakelen</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="52"/>
        <source>Queued</source>
        <translation>In wachtrij</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="53"/>
        <source>Progress</source>
        <translation>Voortgang</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="54"/>
        <source>OK</source>
        <translation>Oké</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="55"/>
        <source>Accepted</source>
        <translation>Geaccepteerd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="56"/>
        <source>Multiple Choices</source>
        <translation>Meerdere mogelijkheden</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="57"/>
        <source>Moved Permanently</source>
        <translation>Permanent verplaatst</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="58"/>
        <source>Moved Temporarily</source>
        <translation>Tijdelijk verplaatst</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="59"/>
        <source>Use Proxy</source>
        <translation>Proxy gebruiken</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="60"/>
        <source>Alternative Service</source>
        <translation>Alternatieve dienst</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="61"/>
        <source>Bad Request</source>
        <translation>Slecht verzoek</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="62"/>
        <source>Unauthorized</source>
        <translation>Niet geautoriseerd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="63"/>
        <source>Payment Required</source>
        <translation>Betaling vereist</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="64"/>
        <source>Forbidden</source>
        <translation>Verboden</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="65"/>
        <source>Not Found</source>
        <translation>Niet gevonden</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="66"/>
        <source>Method Not Allowed</source>
        <translation>Methode niet toegestaan</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="67"/>
        <location filename="../src/newcallmodel.cpp" line="87"/>
        <source>Not Acceptable</source>
        <translation>Niet acceptabel</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="68"/>
        <source>Proxy Authentication Required</source>
        <translation>Proxy-authenticatie vereist</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="69"/>
        <source>Request Timeout</source>
        <translation>Time-out aanvragen</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="70"/>
        <source>Gone</source>
        <translation>Weg</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="71"/>
        <source>Request Entity Too Large</source>
        <translation>Verzoeksentiteit te groot</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="72"/>
        <source>Request URI Too Long</source>
        <translation>Verzoeks-URI te lang</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="73"/>
        <source>Unsupported Media Type</source>
        <translation>Niet-ondersteund mediatype</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="74"/>
        <source>Unsupported URI Scheme</source>
        <translation>Niet-ondersteund URI-schema</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="75"/>
        <source>Bad Extension</source>
        <translation>Slechte extensie</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="76"/>
        <source>Extension Required</source>
        <translation>Extensie vereist</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="77"/>
        <source>Session Timer Too Small</source>
        <translation>Sessietimer te klein</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="78"/>
        <source>Interval Too Brief</source>
        <translation>Interval te kort</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="79"/>
        <source>Temporarily Unavailable</source>
        <translation>Tijdelijk niet beschikbaar</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="80"/>
        <source>Call TSX Does Not Exist</source>
        <translation>Oproep-TSX bestaat niet</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="81"/>
        <source>Loop Detected</source>
        <translation>Lus gedetecteerd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="82"/>
        <source>Too Many Hops</source>
        <translation>Te veel sprongen</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="83"/>
        <source>Address Incomplete</source>
        <translation>Onvolledig adres</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="84"/>
        <source>Ambiguous</source>
        <translation>Ambigu</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="85"/>
        <source>Busy</source>
        <translation>Bezet</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="86"/>
        <source>Request Terminated</source>
        <translation>Verzoek beëindigd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="88"/>
        <source>Bad Event</source>
        <translation>Slechte gebeurtenis</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="89"/>
        <source>Request Updated</source>
        <translation>Verzoek bijgewerkt</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="90"/>
        <source>Request Pending</source>
        <translation>Verzoek in afwachting</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="91"/>
        <source>Undecipherable</source>
        <translation>Onleesbaar</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="92"/>
        <source>Internal Server Error</source>
        <translation>Interne serverfout</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="93"/>
        <source>Not Implemented</source>
        <translation>Niet geïmplementeerd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="94"/>
        <source>Bad Gateway</source>
        <translation>Slechte gateway</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="95"/>
        <source>Service Unavailable</source>
        <translation>Dienst niet beschikbaar</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="96"/>
        <source>Server Timeout</source>
        <translation>Servertime-out</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="97"/>
        <source>Version Not Supported</source>
        <translation>Versie niet ondersteund</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="98"/>
        <source>Message Too Large</source>
        <translation>Bericht te groot</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="99"/>
        <source>Precondition Failure</source>
        <translation>Pre-voorwaardefout</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="100"/>
        <source>Busy Everywhere</source>
        <translation>Overal bezet</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="101"/>
        <source>Call Refused</source>
        <translation>Oproep geweigerd</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="102"/>
        <source>Does Not Exist Anywhere</source>
        <translation>Bestaat nergens</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="103"/>
        <source>Not Acceptable Anywhere</source>
        <translation>Nergens acceptabel</translation>
    </message>
</context>
<context>
    <name>lrc::ContactModelPimpl</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="405"/>
        <source>Searchingâ¦</source>
        <translation>Bezig met zoekenâ¦</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="765"/>
        <source>Invalid ID</source>
        <translation>Ongeldig ID</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="768"/>
        <source>Registered name not found</source>
        <translation>Geregistreerde naam niet gevonden</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="771"/>
        <source>Couldn&apos;t lookupâ¦</source>
        <translation>Kon niet opzoekenâ¦</translation>
    </message>
</context>
<context>
    <name>lrc::api::ContactModel</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="371"/>
        <source>Bad URI scheme</source>
        <translation>Verkeerd URI-schema</translation>
    </message>
</context>
</TS>
